pub struct PathingGrid {
    pub grid: BoolGrid,
    pub neighbours: SimpleGrid<u8>,
    pub components: UnionFind<usize>,
    pub components_dirty: bool,
}
PathingGrid maintains information about components using a UnionFind structure in addition to the raw bool grid values in the BoolGrid that determine whether a space is occupied (true) or empty (false). It also records neighbours in u8 format for fast lookups during search. Implements Grid by building on BoolGrid.

Fields

grid: BoolGridneighbours: SimpleGrid<u8>components: UnionFind<usize>components_dirty: bool

Implementations

Retrieves the component id a given Point belongs to.

Checks if start and goal are on the same component.

Checks if any neighbour of the goal is on the same component as the start.

Computes a path from start to goal using JPS. If approximate is true, then it will path to one of the neighbours of the goal, which is useful if goal itself is blocked. The heuristic used is the Chebyshev distance.

Computes a path from start to one of the given goals. This is done by taking the Chebyshev distance to the closest goal as heuristic value.

The raw waypoints (jump points) from which get_path_multiple_goals makes a path.

The raw waypoints (jump points) from which get_path_single_goal makes a path.

Regenerates the components if they are marked as dirty.

Generates a new UnionFind structure and links up grid neighbours to the same components.