Struct grid_pathfinding::PathingGrid
source · [−]pub struct PathingGrid {
pub grid: BoolGrid,
pub neighbours: SimpleGrid<u8>,
pub components: UnionFind<usize>,
pub components_dirty: bool,
}Expand description
PathingGrid maintains information about components using a UnionFind structure in addition to the raw bool grid values in the BoolGrid that determine whether a space is occupied (true) or empty (false). It also records neighbours in u8 format for fast lookups during search. Implements Grid by building on BoolGrid.
Fields
grid: BoolGridneighbours: SimpleGrid<u8>components: UnionFind<usize>components_dirty: boolImplementations
sourceimpl PathingGrid
impl PathingGrid
sourcepub fn get_component(&self, point: &Point) -> usize
pub fn get_component(&self, point: &Point) -> usize
Retrieves the component id a given Point belongs to.
sourcepub fn unreachable(&self, start: &Point, goal: &Point) -> bool
pub fn unreachable(&self, start: &Point, goal: &Point) -> bool
Checks if start and goal are on the same component.
sourcepub fn neighbours_unreachable(&self, start: &Point, goal: &Point) -> bool
pub fn neighbours_unreachable(&self, start: &Point, goal: &Point) -> bool
Checks if any neighbour of the goal is on the same component as the start.
sourcepub fn get_path_single_goal(
&self,
start: Point,
goal: Point,
approximate: bool
) -> Option<Vec<Point>>
pub fn get_path_single_goal(
&self,
start: Point,
goal: Point,
approximate: bool
) -> Option<Vec<Point>>
Computes a path from start to goal using JPS. If approximate is true, then it will path to one of the neighbours of the goal, which is useful if goal itself is blocked. The heuristic used is the Chebyshev distance.
sourcepub fn get_path_multiple_goals(
&self,
start: Point,
goals: Vec<&Point>
) -> Option<(Point, Vec<Point>)>
pub fn get_path_multiple_goals(
&self,
start: Point,
goals: Vec<&Point>
) -> Option<(Point, Vec<Point>)>
Computes a path from start to one of the given goals. This is done by taking the Chebyshev distance to the closest goal as heuristic value.
sourcepub fn get_waypoints_multiple_goals(
&self,
start: Point,
goals: Vec<&Point>
) -> Option<(Point, Vec<Point>)>
pub fn get_waypoints_multiple_goals(
&self,
start: Point,
goals: Vec<&Point>
) -> Option<(Point, Vec<Point>)>
The raw waypoints (jump points) from which get_path_multiple_goals makes a path.
sourcepub fn get_waypoints_single_goal(
&self,
start: Point,
goal: Point,
approximate: bool
) -> Option<Vec<Point>>
pub fn get_waypoints_single_goal(
&self,
start: Point,
goal: Point,
approximate: bool
) -> Option<Vec<Point>>
The raw waypoints (jump points) from which get_path_single_goal makes a path.
sourcepub fn generate_components(&mut self)
pub fn generate_components(&mut self)
Generates a new UnionFind structure and links up grid neighbours to the same components.